abacusai.pipeline_step — AbacusAI documentation

# `abacusai.pipeline_step`

## Module Contents

### Classes

`PipelineStep` | A step in a pipeline.

class abacusai.pipeline_step.PipelineStep(client, pipelineStepId=None, pipelineId=None, stepName=None, pipelineName=None, createdAt=None, updatedAt=None, pythonFunctionId=None, stepDependencies=None, pythonFunction={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A step in a pipeline.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - pipelineStepId (str) – The reference to this step.

    - pipelineId (str) – The reference to the pipeline this step belongs to.

    - stepName (str) – The name of the step.

    - pipelineName (str) – The name of the pipeline this step is a part of.

    - createdAt (str) – The date and time which this step was created.

    - updatedAt (str) – The date and time when this step was last updated.

    - pythonFunctionId (str) – The python function_id.

    - stepDependencies (list[str]) – List of steps this step depends on.

    - pythonFunction (PythonFunction) – Information about the python function for the step.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict